{-# LANGUAGE OverloadedStrings #-}

-- | Provides [ARIA](https://www.w3.org/TR/wai-aria-1.1/) attributes that can be
-- used to add accessibility annotations to Lucid templates. This module is
-- intended to be imported qualified, e.g., as @Aria@.
module Lucid.Aria where

import Data.Text (Text)
import Lucid.Base (Attribute, makeAttribute)

-- | The @aria-busy@ attribute.
busy_ :: Text -> Attribute
busy_ = makeAttribute "aria-busy"

-- | The @aria-checked@ attribute.
checked_ :: Text -> Attribute
checked_ = makeAttribute "aria-checked"

-- | The @aria-disabled@ attribute.
disabled_ :: Text -> Attribute
disabled_ = makeAttribute "aria-disabled"

-- | The @aria-expanded@ attribute.
expanded_ :: Text -> Attribute
expanded_ = makeAttribute "aria-expanded"

-- | The @aria-grabbed@ attribute.
grabbed_ :: Text -> Attribute
grabbed_ = makeAttribute "aria-grabbed"

-- | The @aria-hidden@ attribute.
hidden_ :: Text -> Attribute
hidden_ = makeAttribute "aria-hidden"

-- | The @aria-invalid@ attribute.
invalid_ :: Text -> Attribute
invalid_ = makeAttribute "aria-invalid"

-- | The @aria-pressed@ attribute.
pressed_ :: Text -> Attribute
pressed_ = makeAttribute "aria-pressed"

-- | The @aria-selected@ attribute.
selected_ :: Text -> Attribute
selected_ = makeAttribute "aria-selected"

-- | The @aria-activedescendant@ attribute.
activedescendant_ :: Text -> Attribute
activedescendant_ = makeAttribute "aria-activedescendant"

-- | The @aria-atomic@ attribute.
atomic_ :: Text -> Attribute
atomic_ = makeAttribute "aria-atomic"

-- | The @aria-autocomplete@ attribute.
autocomplete_ :: Text -> Attribute
autocomplete_ = makeAttribute "aria-autocomplete"

-- | The @aria-controls@ attribute.
controls_ :: Text -> Attribute
controls_ = makeAttribute "aria-controls"

-- | The @aria-describedby@ attribute.
describedby_ :: Text -> Attribute
describedby_ = makeAttribute "aria-describedby"

-- | The @aria-dropeffect@ attribute.
dropeffect_ :: Text -> Attribute
dropeffect_ = makeAttribute "aria-dropeffect"

-- | The @aria-flowto@ attribute.
flowto_ :: Text -> Attribute
flowto_ = makeAttribute "aria-flowto"

-- | The @aria-haspopup@ attribute.
haspopup_ :: Text -> Attribute
haspopup_ = makeAttribute "aria-haspopup"

-- | The @aria-label@ attribute.
label_ :: Text -> Attribute
label_ = makeAttribute "aria-label"

-- | The @aria-labelledby@ attribute.
labelledby_ :: Text -> Attribute
labelledby_ = makeAttribute "aria-labelledby"

-- | The @aria-level@ attribute.
level_ :: Text -> Attribute
level_ = makeAttribute "aria-level"

-- | The @aria-live@ attribute.
live_ :: Text -> Attribute
live_ = makeAttribute "aria-live"

-- | The @aria-multiline@ attribute.
multiline_ :: Text -> Attribute
multiline_ = makeAttribute "aria-multiline"

-- | The @aria-multiselectable@ attribute.
multiselectable_ :: Text -> Attribute
multiselectable_ = makeAttribute "aria-multiselectable"

-- | The @aria-orientation@ attribute.
orientation_ :: Text -> Attribute
orientation_ = makeAttribute "aria-orientation"

-- | The @aria-owns@ attribute.
owns_ :: Text -> Attribute
owns_ = makeAttribute "aria-owns"

-- | The @aria-posinset@ attribute.
posinset_ :: Text -> Attribute
posinset_ = makeAttribute "aria-posinset"

-- | The @aria-readonly@ attribute.
readonly_ :: Text -> Attribute
readonly_ = makeAttribute "aria-readonly"

-- | The @aria-relevant@ attribute.
relevant_ :: Text -> Attribute
relevant_ = makeAttribute "aria-relevant"

-- | The @aria-required@ attribute.
required_ :: Text -> Attribute
required_ = makeAttribute "aria-required"

-- | The @aria-setsize@ attribute.
setsize_ :: Text -> Attribute
setsize_ = makeAttribute "aria-setsize"

-- | The @aria-sort@ attribute.
sort_ :: Text -> Attribute
sort_ = makeAttribute "aria-sort"

-- | The @aria-valuemax@ attribute.
valuemax_ :: Text -> Attribute
valuemax_ = makeAttribute "aria-valuemax"

-- | The @aria-valuemin@ attribute.
valuemin_ :: Text -> Attribute
valuemin_ = makeAttribute "aria-valuemin"

-- | The @aria-valuenow@ attribute.
valuenow_ :: Text -> Attribute
valuenow_ = makeAttribute "aria-valuenow"

-- | The @aria-valuetext@ attribute.
valuetext_ :: Text -> Attribute
valuetext_ = makeAttribute "aria-valuetext"
